==> falkon_3.1.0.orig.tar.xz: falkon-3.1.0/src/plugins/StatusBarIcons/statusbariconsplugin.h <==
/* ============================================================
* StatusBarIcons - Extra icons in statusbar for Falkon
* Copyright (C) 2013-2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef STATUSBARICONSPLUGIN_H
#define STATUSBARICONSPLUGIN_H

#include "plugininterface.h"

class SBI_IconsManager;

class StatusBarIconsPlugin : public QObject, public PluginInterface
{
    Q_OBJECT
    Q_INTERFACES(PluginInterface)
    Q_PLUGIN_METADATA(IID "Falkon.Browser.plugin.StatusBarIcons")

public:
    explicit StatusBarIconsPlugin();

    DesktopFile metaData() const override;
    void init(InitState state, const QString &settingsPath) override;
    void unload() override;
    bool testPlugin() override;
    void showSettings(QWidget *parent) override;

private:
    SBI_IconsManager* m_manager;

};

#endif // STATUSBARICONSPLUGIN_H

==> falkon_25.08.1.orig.tar.xz: falkon-25.08.1/src/plugins/StatusBarIcons/statusbariconsplugin.h <==
/* ============================================================
* StatusBarIcons - Extra icons in statusbar for Falkon
* Copyright (C) 2013-2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#ifndef STATUSBARICONSPLUGIN_H
#define STATUSBARICONSPLUGIN_H

#include "plugininterface.h"

class SBI_IconsManager;

class StatusBarIconsPlugin : public QObject, public PluginInterface
{
    Q_OBJECT
    Q_INTERFACES(PluginInterface)
    Q_PLUGIN_METADATA(IID "Falkon.Browser.plugin.StatusBarIcons" FILE "statusbaricons.json")

public:
    explicit StatusBarIconsPlugin();

    void init(InitState state, const QString &settingsPath) override;
    void unload() override;
    bool testPlugin() override;
    void showSettings(QWidget *parent) override;

private:
    SBI_IconsManager* m_manager;

};

#endif // STATUSBARICONSPLUGIN_H
